<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Zeréck bei de komplette grapheschen Interface',
	'access_mode_texte' => 'Vereinfachten Text-Interface weisen',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Dësen Artikel änneren',
	'admin_modifier_auteur' => 'Dësen Auteur änneren',
	'admin_modifier_breve' => 'Dës Kuerzmeldung änneren',
	'admin_modifier_mot' => 'Dëst Schlësselwuert änneren',
	'admin_modifier_rubrique' => 'Dës Rubrik änneren',
	'admin_recalculer' => 'Dës Säit nei rechnen',
	'afficher_calendrier' => 'Kalenner weisen',
	'afficher_trad' => 'Iwwersetzunge weisen',
	'alerte_maj_impossible' => '<b>Alarm!</b> Den Update vun der SQL-Datekank op d’Versioun @version@ ass onméiglech, villäicht wéint engem Problem mat de Verännerungs-Rechter vun der Datebank. Kontaktéiert w.e.g. äre Provider.',
	'alerte_modif_info_concourante' => 'OPGEPASST: Dës Informatioun ass geännert ginn. Déi aktuell Valeur ass:',
	'analyse_xml' => 'XML-Analyse',
	'annuler' => 'Ofbriechen',
	'antispam_champ_vide' => 'Loosst dëst Feld eidel:',
	'articles_recents' => 'Déi rezent Artikelen',
	'avis_archive_incorrect' => 'de Backup-Fichier ass kee SPIP-Fichier',
	'avis_archive_invalide' => 'de Backup-Fichier ass ongülteg',
	'avis_attention' => 'OPGEPASST!',
	'avis_champ_incorrect_type_objet' => 'Falsche Feldnumm @name@ fir en Objet vum Typ @type@',
	'avis_colonne_inexistante' => 'D’Kolonn @col@ existéiert net',
	'avis_erreur' => 'Fehler: kuckt hei driwwer',
	'avis_erreur_connexion' => 'Verbindungs-Fehler',
	'avis_erreur_cookie' => 'Problem mat dem Cookie',
	'avis_erreur_fonction_contexte' => 'Programm-Fehler. Dës Fonctioun däerf net an dësem Kontext opgeruff ginn.',
	'avis_erreur_mysql' => 'SQL-Fehler',
	'avis_erreur_sauvegarde' => 'Fehler am Backup (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Zougangs-Problem zum privaten Deel',

	// B
	'barre_a_accent_grave' => 'E groussen A accent grave afügen',
	'barre_aide' => 'Benotzt dës typografesch Ofkierzungen fir äre Layout ze verbesseren',
	'barre_e_accent_aigu' => 'E groussen E accent aigu afügen',
	'barre_eo' => 'E verbonnenen oe afügen',
	'barre_eo_maj' => 'E grousse verbonnenen OE afügen',
	'barre_euro' => 'En €-Symbol afügen',
	'barre_gras' => '{{Fett}} maachen',
	'barre_guillemets' => 'Tëschent franséisch Anführungszeeche setzen',
	'barre_guillemets_simples' => 'Tëschent däitsch Anführungszeeche setzen',
	'barre_intertitre' => 'An eng {{{Iwwerschrëft}}} änneren',
	'barre_italic' => '{Kursiv} maachen',
	'barre_lien' => 'An e [Link->http://...] änneren',
	'barre_lien_input' => 'Gidd d’Adress vum Link un (dir kënnt eng Internet-Adress ënner der Form http://www.site.lu/asw oder einfach d’Nummer vun engem Artikel vun dësem Site uginn.',
	'barre_note' => 'An eng [[Foussnout]] änneren',
	'barre_paragraphe' => 'Abschnitt bäiflécken',
	'barre_quote' => '<quote>Citatioun</quote> vun engem Text',
	'bouton_changer' => 'Änneren',
	'bouton_chercher' => 'Sichen',
	'bouton_choisir' => 'Auswielen',
	'bouton_deplacer' => 'Réckelen',
	'bouton_download' => 'Eroflueden',
	'bouton_enregistrer' => 'Späicheren',
	'bouton_radio_desactiver_messagerie_interne' => 'Déi intern Messagerie ausschalten',
	'bouton_radio_envoi_annonces' => 'Editorial Annoncen schécken',
	'bouton_radio_non_envoi_annonces' => 'Keng Neiegkeeten schécken',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Keng Lëscht vun de Neiegkeeten schécken',
	'bouton_recharger_page' => 'dës Säit nei lueden',
	'bouton_telecharger' => 'Eroflueden',
	'bouton_upload' => 'Eroplueden',
	'bouton_valider' => 'Bestätegen',

	// C
	'cal_apresmidi' => 'Nomëtteg',
	'cal_jour_entier' => 'Ganzen Dag',
	'cal_matin' => 'Mueres',
	'cal_par_jour' => 'Kalenner vum Dag',
	'cal_par_mois' => 'Kalenner vum Mount',
	'cal_par_semaine' => 'Kalenner vun der Woch',
	'choix_couleur_interface' => 'Faarf',
	'choix_interface' => 'Wiel vum Interface',
	'colonne' => 'Kolonn',
	'confirm_changer_statut' => 'Opgepasst, dir wëllt den Zoustand vun dësem Element änneren. Wëllt dir weiderfueren?',
	'correcte' => 'richteg',

	// D
	'date_aujourdhui' => 'haut',
	'date_avant_jc' => 'virun J.C.',
	'date_dans' => 'an @delai@',
	'date_de_mois_1' => '@j@. @nommois@',
	'date_de_mois_10' => '@j@. @nommois@',
	'date_de_mois_11' => '@j@. @nommois@',
	'date_de_mois_12' => '@j@. @nommois@',
	'date_de_mois_2' => '@j@. @nommois@',
	'date_de_mois_3' => '@j@. @nommois@',
	'date_de_mois_4' => '@j@. @nommois@',
	'date_de_mois_5' => '@j@. @nommois@',
	'date_de_mois_6' => '@j@. @nommois@',
	'date_de_mois_7' => '@j@. @nommois@',
	'date_de_mois_8' => '@j@. @nommois@',
	'date_de_mois_9' => '@j@. @nommois@',
	'date_demain' => 'muer',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ um @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ vu @heure_debut@ bis @heure_fin@ Auer', # MODIF
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ vu @heure_debut@@dtabbr@ bis @dtend@@heure_fin@@dtabbr@', # MODIF
	'date_fmt_jour_mois' => '@jour@. @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@. @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@, den @date@',
	'date_fmt_periode' => 'Vum @date_debut@. bis den @date_fin@.',
	'date_fmt_periode_abbr' => 'Vum @dtart@@date_debut@@dtabbr@. bis den @dtend@@date_fin@@dtabbr@.',
	'date_fmt_periode_from' => 'Vum',
	'date_fmt_periode_to' => 'bis den',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'Stonnen',
	'date_hier' => 'gëschter',
	'date_il_y_a' => 'virun @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Sonndeg',
	'date_jour_1_abbr' => 'Son.',
	'date_jour_1_initiale' => 'S',
	'date_jour_2' => 'Méindeg',
	'date_jour_2_abbr' => 'Méi.',
	'date_jour_2_initiale' => 'M',
	'date_jour_3' => 'Dënschdeg',
	'date_jour_3_abbr' => 'Dën.',
	'date_jour_3_initiale' => 'D',
	'date_jour_4' => 'Mëttwoch',
	'date_jour_4_abbr' => 'Mët.',
	'date_jour_4_initiale' => 'M',
	'date_jour_5' => 'Donneschdeg',
	'date_jour_5_abbr' => 'Don.',
	'date_jour_5_initiale' => 'D',
	'date_jour_6' => 'Freideg',
	'date_jour_6_abbr' => 'Fre.',
	'date_jour_6_initiale' => 'F',
	'date_jour_7' => 'Samschdeg',
	'date_jour_7_abbr' => 'Sam.',
	'date_jour_7_initiale' => 'S',
	'date_jours' => 'Deeg',
	'date_minutes' => 'Minutten',
	'date_mois' => 'Méint',
	'date_mois_1' => 'Januar',
	'date_mois_10' => 'Oktober',
	'date_mois_10_abbr' => 'Okt.',
	'date_mois_11' => 'November',
	'date_mois_11_abbr' => 'Nov.',
	'date_mois_12' => 'Dezember',
	'date_mois_12_abbr' => 'Dez.',
	'date_mois_1_abbr' => 'Jan.',
	'date_mois_2' => 'Februar',
	'date_mois_2_abbr' => 'Feb.',
	'date_mois_3' => 'März',
	'date_mois_3_abbr' => 'März',
	'date_mois_4' => 'Abrëll',
	'date_mois_4_abbr' => 'Abr.',
	'date_mois_5' => 'Mee',
	'date_mois_5_abbr' => 'Mee',
	'date_mois_6' => 'Juni',
	'date_mois_6_abbr' => 'Juni',
	'date_mois_7' => 'Juli',
	'date_mois_7_abbr' => 'Juli',
	'date_mois_8' => 'August',
	'date_mois_8_abbr' => 'Aug.',
	'date_mois_9' => 'September',
	'date_mois_9_abbr' => 'Sep.',
	'date_saison_1' => 'Wanter',
	'date_saison_2' => 'Fréijor',
	'date_saison_3' => 'Summer',
	'date_saison_4' => 'Hierscht',
	'date_secondes' => 'Sekonnen',
	'date_semaines' => 'Wochen',
	'date_un_mois' => 'Mount',
	'date_une_heure' => 'Stonn',
	'date_une_minute' => 'Minutt',
	'date_une_seconde' => 'Sekonn',
	'date_une_semaine' => 'Woch',
	'dirs_commencer' => ' fir d’Installatioun richteg unzefänken',
	'dirs_preliminaire' => 'Fir d’éischt: <b>Regléiert d’Zougangsberechtegung</b>',
	'dirs_probleme_droits' => 'Problem mat der Zougangsberechtegung',
	'dirs_repertoires_absents' => '<p><b>Dës Dossieren konnten net fonnt ginn:</b></p><ul>@bad_dirs@.</ul>
<p>Wahrscheinlech ass et e Problem vu grouss- oder kleng-schreiwen.
Kontrolléiert op déi grouss an déi kleng Buschtawen mat deem wat hei ugewisen gëtt iwwerteneestëmmen;
wann dat net de Fall ass, ännert de Numm vun den Dossieren mat ärem FTP-Client fir de Fehler ze verbesseren.
<p>Wann dat gemaach ass, da kënnt dier',
	'dirs_repertoires_suivants' => '<p><b>Dës Dossieren kënnen net beschriwwe ginn:</b></p><ul>@bad_dirs@.</ul>
<p>Fir dat ze verbesseren, benotzt ären FTP-Client fir d’Zougangsberechtegung vu jidder Dossier anzestellen.
Dës Prozedur ass am Detail am Installatiouns-Guide beschriwwen.<p>
<p>Wann dat gemaach ass, da kënnt dier ',
	'double_occurrence' => '@balise@ ass duebel',

	// E
	'en_cours' => 'am gaangen',
	'envoi_via_le_site' => 'Via äre Site schécken',
	'erreur' => 'Fehler',
	'erreur_balise_non_fermee' => 'Läschten Tag dee net zou ass:',
	'erreur_technique_ajaxform' => 'Oups. E Fehler verhennert d’Fortschécke vum Formulaire. Probéiert nach eng Kéier.',
	'erreur_technique_enregistrement_champs' => 'En technesche Problem verhënnert d’Späichere vum Feld @champs@.',
	'erreur_technique_enregistrement_impossible' => 'En technesche Problem verhënnert d’Späicheren.',
	'erreur_texte' => 'Fehler(en)',
	'etape' => 'Schrëtt',

	// F
	'fichier_introuvable' => 'De Fichier @fichier@ ka net fonnt ginn', # MODIF
	'form_auteur_confirmation' => 'Bestätegt är Email-Adress.',
	'form_auteur_email_modifie' => 'Är Email-Adress ass geännert.',
	'form_auteur_envoi_mail_confirmation' => 'En Email ass un @email@ geschéckt ginn. Dir musst op d’URL surfen déi an deem Email steet fir är Email-Adress ze bestätegen.',
	'form_auteur_mail_confirmation' => 'Bonjour,

Dir wëllt är Email-Adress ze änneren.
Fir är nei Adress ze bestätegen, surft op dës URL (soss gëtt är Ufro ignoréiert):

    @url@
',
	'form_deja_inscrit' => 'Dir sidd schonns ugemellt.',
	'form_email_non_valide' => 'Är Email-Adress ass net richteg.',
	'form_forum_access_refuse' => 'Dir hutt keen Zougang méi zu dësem Site.',
	'form_forum_bonjour' => 'Bonjour @nom@,',
	'form_forum_confirmer_email' => 'Fir är Email-Adress ze bestätegen, surft op dës URL: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Dës Email-Adress ass schonns ageschriwwen, dir kënnt also äert normaalt Passwuert benotzen.',
	'form_forum_identifiant_mail' => 'Äre neie Login gouf Iech elo grad per Email geschéckt.',
	'form_forum_identifiants' => 'Perséinlech Identifikatioun',
	'form_forum_indiquer_nom_email' => 'Gidd hei äre Numm an är Email-Adress un. Äre perséinlechen Login kritt der per Email geschéckt.',
	'form_forum_login' => 'Login:',
	'form_forum_message_auto' => '(dëst ass eng automatesch Äntwert)',
	'form_forum_pass' => 'Passwuert:',
	'form_forum_probleme_mail' => 'Problem mam Email: de Login ka net verschéckt ginn.',
	'form_forum_voici1' => 'Hei ass är Identifikatioun fir beim Site "@nom_site_spip@" (@adresse_site@) matzemaachen:',
	'form_forum_voici2' => 'Hei ass är Identifikatioun fir Artikelen um Site "@nom_site_spip@" (@adresse_login@) virzeschloen:',
	'form_indiquer_email' => 'Gidd w.e.g. är Email-Adress un.',
	'form_indiquer_nom' => 'Gidd w.e.g. äre Numm un.',
	'form_indiquer_nom_site' => 'Gidd w.e.g. de Numm vun ärem Site un.',
	'form_pet_deja_enregistre' => 'Dëse Site ass schonns ageschriwwen',
	'form_pet_signature_pasprise' => 'Är Ënnerschrëft ass net ugeholl ginn.',
	'form_prop_confirmer_envoi' => 'Konfirméiert d’Schécken',
	'form_prop_description' => 'Beschreiwung/Kommentar',
	'form_prop_enregistre' => 'Är Propositioun ass enregistréiert, si geet online wann se vun engem Responsabelen vun dësem Site bestätegt ass.', # MODIF
	'form_prop_envoyer' => 'E Message schécken',
	'form_prop_indiquer_email' => 'Gidd w.e.g. eng richteg Email-Adress un',
	'form_prop_indiquer_nom_site' => 'Gidd w.e.g. de Numm vum Site un.',
	'form_prop_indiquer_sujet' => 'Gidd w.e.g. eng Iwwerschrëft un',
	'form_prop_message_envoye' => 'Message geschéckt',
	'form_prop_non_enregistre' => 'Äre Virschlag ass net enregistréiert ginn.',
	'form_prop_sujet' => 'Iwwerschrëft',
	'form_prop_url_site' => 'Adress (URL) vum Site',
	'forum_non_inscrit' => 'Dir sidd net ugemellt, oder d’Adress oder d’Passwuert ass falsch.',
	'forum_par_auteur' => 'No @auteur@',
	'forum_titre_erreur' => 'Fehler...',

	// I
	'ical_texte_rss_articles' => 'Den RSS-Fichier vun den Artikele vun dësem Site ass op der Adress:',
	'ical_texte_rss_articles2' => 'Dir kënnt och RSS-Fichieren fir d’Artikele vun all Rubrik vum Site kréien:',
	'ical_texte_rss_breves' => 'Et gëtt och e Fichier mat de Kuerzmeldunge vum Site. Wann dir d’Nummer vun enger Rubrik agitt, da kritt der just d’Kuerzmeldunge vun där Rubrik.',
	'icone_a_suivre' => 'Aufgaben',
	'icone_admin_site' => 'Administratioun vum Site',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Hëllef',
	'icone_articles' => 'Artikelen',
	'icone_auteurs' => 'Auteuren',
	'icone_brouteur' => 'Schnell-Navigatioun',
	'icone_configuration_site' => 'Astellungen',
	'icone_configurer_site' => 'Äre Site astellen',
	'icone_creer_nouvel_auteur' => 'Auteur bäiflécken',
	'icone_creer_rubrique' => 'Rubrik bäiflécken',
	'icone_creer_sous_rubrique' => 'Ënner-Rubrik bäiflécken',
	'icone_deconnecter' => 'Sech ofmellen',
	'icone_discussions' => 'Diskussiounen',
	'icone_doc_rubrique' => 'Dokumenter',
	'icone_ecrire_article' => 'Neien Artikel schreiwen',
	'icone_edition_site' => 'Ännerung',
	'icone_gestion_langues' => 'Sprooch-Astellungen',
	'icone_informations_personnelles' => 'Perséinlech Informatiounen',
	'icone_interface_complet' => 'Kompletten Interface',
	'icone_interface_simple' => 'Einfachen Interface',
	'icone_maintenance_site' => 'Maintenance vum Site',
	'icone_messagerie_personnelle' => 'Perséinlech Messagerie',
	'icone_repartition_debut' => 'D’Verdeelung säit dem Ufank weisen',
	'icone_rubriques' => 'Rubriken',
	'icone_sauver_site' => 'Site späicheren',
	'icone_site_entier' => 'De ganzen Site',
	'icone_sites_references' => 'Verlinkte Siten',
	'icone_statistiques' => 'Statistik vum Site',
	'icone_suivi_activite' => 'D’Liewen vum Site verfollegen',
	'icone_suivi_actualite' => 'Evolutioun vum Site',
	'icone_suivi_pettions' => 'Petitioune verfollegen',
	'icone_suivi_revisions' => 'Ännerunge vun den Artikelen',
	'icone_supprimer_document' => 'Dëst Dokument läschen',
	'icone_supprimer_image' => 'Dëst Bild läschen',
	'icone_tous_articles' => 'All är Artikelen',
	'icone_tous_auteur' => 'All d’Auteuren',
	'icone_tous_visiteur' => 'All d’Visiteuren',
	'icone_visiter_site' => 'Den ëffentleche Site weisen',
	'icone_voir_en_ligne' => 'Online weisen',
	'img_indisponible' => 'Bild fehlt',
	'impossible' => 'onméiglech',
	'info_a_suivre' => 'AUFGABEN"',
	'info_acces_interdit' => 'Zougang gespaart',
	'info_acces_refuse' => 'Zougang gespaart',
	'info_action' => 'Aktioun: @action@',
	'info_administrer_rubriques' => 'Dir kënnt dës Rubrik an hier Ënner-Rubriken verwalten',
	'info_adresse_non_indiquee' => 'Dir hutt keng Test-Adress uginn!',
	'info_aide' => 'HËLLEF:',
	'info_ajouter_mot' => 'Dëst Wuert bäiflécken',
	'info_annonce' => 'ANNONCE',
	'info_annonces_generales' => 'Generell Annoncen:',
	'info_article_propose' => 'Proposéierten Artikel',
	'info_article_publie' => 'Verëffentlechten Artikel',
	'info_article_redaction' => 'Artikel an der Aarbecht',
	'info_article_refuse' => 'Ofgeleenten Artikel',
	'info_article_supprime' => 'Geläschten Artikel',
	'info_articles' => 'Artikelen',
	'info_articles_a_valider' => 'Artikelen fir ze bestätegen',
	'info_articles_nb' => '@nb@ Artikelen',
	'info_articles_proposes' => 'Virgeschloen Artikelen',
	'info_articles_un' => '1 Artikel',
	'info_auteurs_nombre' => 'Auteur(en):',
	'info_authentification_ftp' => 'Umeldung (per FTP).',
	'info_breves_2' => 'Kuerzmeldungen',
	'info_breves_nb' => '@nb@ Kurzmeldungen',
	'info_breves_un' => '1 Kurzmeldung',
	'info_connexion_refusee' => 'D’Verbindung gouf ofgeleent.',
	'info_contact_developpeur' => 'Kontaktéiert w.e.g. en Entwéckler.', # MODIF
	'info_contenance' => 'Dëse Site huet:',
	'info_contribution' => 'Bäiträg',
	'info_copyright' => '@spip@ ass eng fräi Software déi ënner @lien_gpl@ verdeelt gëtt.',
	'info_copyright_doc' => 'Fir méi Informatioune, kuckt de Site <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'ënner GPL-Lizenz',
	'info_cours_edition' => 'Är Artikelen an der Aarbecht', # MODIF
	'info_creer_repertoire' => 'Fléckt e Fichier oder Dossier mat dësem Numm:',
	'info_creer_repertoire_2' => 'am Dossier <b>ecrire/data</b> bäi, dann:',
	'info_creer_vignette' => 'Vignetten automatesch maachen',
	'info_creerdansrubrique_non_autorise' => 'Dir hutt net genuch Rechter fir an dëser Rubrik Inhalt bäizeflécken',
	'info_deplier' => 'Opklappen',
	'info_descriptif_nombre' => 'Beschreiwung(en):',
	'info_description' => 'Beschreiwung:',
	'info_description_2' => 'Beschreiwung:',
	'info_dimension' => 'Gréisst:',
	'info_documents_nb' => '@nb@ Dokumenter',
	'info_documents_un' => '1 Dokument',
	'info_ecire_message_prive' => 'E privaten Message schécken',
	'info_email_invalide' => 'Falsch Email-Adress.',
	'info_en_cours_validation' => 'Är Artikelen an der Aarbecht',
	'info_en_ligne' => 'Elo online:',
	'info_envoyer_message_prive' => 'Dësem Auteur e privaten Message schécken',
	'info_erreur_requete' => 'Fehler am Query:',
	'info_erreur_squelette2' => 'Et gëtt kee Skelett <b>@fichier@</b> ...',
	'info_erreur_systeme' => 'System-Fehler (errno @errsys@)',
	'info_erreur_systeme2' => 'Den Harddisk ass villäicht voll oder d’Datebank futti.
<span style=\'color:#f00\'>Versicht <a href=\'@script@\'>d’Datebank ze flécken</a>,
oder kontaktéiert äre Provider.</span>',
	'info_fini' => 'Et ass fäerdeg!',
	'info_format_image' => 'Bild-Formater déi kënnen benotzt ginn fir Vignetten ze maachen: @gd_formats@.',
	'info_format_non_defini' => 'Format net definéiert',
	'info_grand_ecran' => 'Groussen Bildschierm',
	'info_image_aide' => 'HËLLEF',
	'info_image_process_titre' => 'Fabrikatiouns-Method fir d’Vignetten',
	'info_impossible_lire_page' => '<b>Fehler!</b> Onméiglech d’Säit <tt><html>@test_proxy@</html></tt> duerch de Proxy ze liesen',
	'info_installation_systeme_publication' => 'Ariichte vum System...',
	'info_installer_documents' => 'Dir kënnt automatesch all d’Dokumenter aus dem Dossier @upload@ installéieren.',
	'info_installer_ftp' => 'Als Administrateur kënnt dir Fichieren per FTP an den Dossier @upload@ eroplueden an se dann hei auswielen.', # MODIF
	'info_installer_images' => 'Dir kënnt Biller am Format JPEG, GIF oder PNG eroplueden.',
	'info_installer_images_dossier' => 'Biller an den Dossier @upload@ eroplueden fir se hei kënnen auszewielen.',
	'info_interface_complete' => 'Kompletten Interface',
	'info_interface_simple' => 'Einfachen Interface',
	'info_joindre_document_article' => 'Dier kënnt dësem Artikel Dokumenter bäiflécke vum Typ',
	'info_joindre_document_rubrique' => 'Dir kënnt dëser Rubrik Dokumenter bäiflécken vum Typ',
	'info_joindre_documents_article' => 'Dir kënnt dësem Artikel Dokumenter bäiflécke vum Typ:',
	'info_l_article' => 'den Artikel',
	'info_la_breve' => 'd’Kuerzmeldung',
	'info_la_rubrique' => 'd’Rubrik',
	'info_langue_principale' => 'Haaptsprooch vum Site',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ Pixel',
	'info_les_auteurs_1' => 'vun @les_auteurs@',
	'info_logo_format_interdit' => 'Nëmmen Logoe mam Format @formats@ ginn ugeholl.',
	'info_logo_max_poids' => 'Logoe mussen manner wéi @maxi@ hunn (dëse
Fichier huet @actuel@).',
	'info_mail_fournisseur' => 'numm@provider.lu',
	'info_message_2' => 'MESSAGE',
	'info_message_supprime' => 'MESSAGE GELÄSCHT',
	'info_messages_nb' => '@nb@ Messagen',
	'info_messages_un' => '1 Message',
	'info_mise_en_ligne' => 'Datum vun der Verëffentlechung:',
	'info_modification_parametres_securite' => 'Änneren vun de Sécherheets-Astellungen',
	'info_mois_courant' => 'An dësem Mount:',
	'info_mot_cle_ajoute' => 'D’Schlësselwuert gouf bäigefléckt bei',
	'info_multi_herit' => 'Haaptsprooch',
	'info_multi_langues_soulignees' => 'Déi <u>ënnerstrache Sproochen</u> hunn en Interface dee komplett oder deelweis iwwersat ass. Wann dier dës Sprooche wielt, da gi vill Elementer vum ëffentleche Site (Datume, Formulairen) automatesch iwwersat. Bei de net ënnerstrache Sproochen erschéngen dës Elementer an der Haaptsprooch vum Site.',
	'info_multilinguisme' => 'Verschidde Sproochen',
	'info_nom_non_utilisateurs_connectes' => 'Äre Numm ass net op der Lëscht vun den ugemellte Benotzer.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Äre Numm kënnt op d’Lëscht vun den ugemellte Benotzer.', # MODIF
	'info_nombre_en_ligne' => 'Elo ugemellt:',
	'info_non_resultat' => 'Kee Resultat fir "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Dir benotzt déi intern Messagerie vun dësem Site net.',
	'info_nouveau_message' => 'DIER HUTT E NEIE MESSAGE',
	'info_nouveaux_messages' => 'DIR HUTT @total_messages@ NEI MESSAGEN',
	'info_numero_abbreviation' => 'Nr. ',
	'info_obligatoire' => 'Dës Informatioun ass obligatoresch',
	'info_pense_bete' => 'NOTIZBLOCK',
	'info_petit_ecran' => 'Klengen Bildschierm',
	'info_petition_close' => 'Petitioun ofgeschloss',
	'info_pixels' => 'Pixel',
	'info_plusieurs_mots_trouves' => 'E puer Schlësselwierder fonnt fir "@cherche_mot@":',
	'info_portfolio_automatique' => 'Automatesche Portfolio:',
	'info_premier_resultat' => '[@debut_limit@ éischt Resultater vun @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ éischt Resultater vun @total@]',
	'info_propose_1' => '[@nom_site_spip@] Virgeschloe: @titre@',
	'info_propose_2' => 'Virgeschloenen Artikel
---------------------',
	'info_propose_3' => 'Den Artikel "@titre@" gëtt fir d’Verëffentlechung virgeschlolen.',
	'info_propose_4' => 'Dir sidd agelueden Iech en unzekucken an ären Avis ze ginn',
	'info_propose_5' => 'am Forum deen zu him gehéiert. Dir fannt en op der Adress:',
	'info_publie_01' => 'Den Artikel "@titre@" ass vum @connect_nom@ bestätegt ginn.',
	'info_publie_1' => '[@nom_site_spip@] VERËFFENTLECHT: @titre@',
	'info_publie_2' => 'Verëffentlechten Artikel
---------------------',
	'info_rechercher' => 'Sichen',
	'info_rechercher_02' => 'Sichen:',
	'info_remplacer_vignette' => 'D’Vignette duerch e extra Logo ersetzen:',
	'info_rubriques_nb' => '@nb@ Rubriken',
	'info_rubriques_un' => '1 Rubrik',
	'info_sans_titre_2' => 'ouni Titel',
	'info_selectionner_fichier' => 'Dir kënnt e Fichier aus dem Dossier @upload@ wielen',
	'info_selectionner_fichier_2' => 'Wielt e Fichier:',
	'info_sites_nb' => '@nb@ Websiten',
	'info_sites_un' => '1 Website',
	'info_supprimer_vignette' => 'Vignette läschen',
	'info_symbole_bleu' => 'Dat <b>blot</b> Symbol weist eng <b>Notiz</b>, also e perséinlechen Message.',
	'info_symbole_jaune' => 'Dat <b>gielt</b> Symbol weist eng <b>Annonce un all d’Redakteren</b>, ännerbar duerch d’Administrateuren, a siichtbar vun alle Redakteren.', # MODIF
	'info_symbole_vert' => 'Dat <b>gréngt</b> Symbol weist <b>Messagen tëschent de Benotzer</b> vum Site.', # MODIF
	'info_telecharger_nouveau_logo' => 'E neie Logo eroplueden:',
	'info_telecharger_ordinateur' => 'Vun ärem Computer eroplueden:',
	'info_tous_resultats_enregistres' => '[all d’Resultater si gespäichert]',
	'info_tout_afficher' => 'Alles weisen',
	'info_travaux_texte' => 'Dëse Site ass nach net ageriicht. Kommt méi spéit erëm...',
	'info_travaux_titre' => 'Chantier um Site',
	'info_trop_resultat' => 'Ze vill Resultater fir "@cherche_mot@"; verbessert är Sich.',
	'info_utilisation_messagerie_interne' => 'Dir kënnt déi intern Messagerie vun dësem Site benotzen.',
	'info_valider_lien' => 'dëse Link bestätegen',
	'info_verifier_image' => ', kontrolléiert op är Biller richteg gelueden goufen.',
	'info_vignette_defaut' => 'Defaut-Vignette',
	'info_vignette_personnalisee' => 'Personaliséiert Vignette',
	'info_visite' => 'Visite:',
	'info_vos_rendez_vous' => 'Är Rendezvous’en',
	'infos_vos_pense_bete' => 'Är Notizen',

	// L
	'label_ajout_id_rapide' => 'Schnell-Ännerung',
	'label_poids_fichier' => 'Gréisst',
	'lien_afficher_icones_seuls' => 'Nëmmen d’Ikone weisen',
	'lien_afficher_texte_icones' => 'D’Ikonen an d’Texter weisen',
	'lien_afficher_texte_seul' => 'Nëmmen d’Texter weisen',
	'lien_liberer' => 'fräi ginn',
	'lien_liberer_tous' => 'Alles fräi ginn',
	'lien_nouvea_pense_bete' => 'NEI NOTIZ',
	'lien_nouveau_message' => 'NEIE MESSAGE',
	'lien_nouvelle_annonce' => 'NEI ANNONCE',
	'lien_petitions' => 'PETITIOUN',
	'lien_popularite' => 'Popularitéit: @popularite@%',
	'lien_racine_site' => 'WUERZEL VUM SITE',
	'lien_reessayer' => 'nach eng Kéier probéieren',
	'lien_repondre_message' => 'Op dëse Message äntweren',
	'lien_supprimer' => 'läschen',
	'lien_tout_afficher' => 'Alles weisen',
	'lien_visite_site' => 'dëse Site kucken',
	'lien_visites' => '@visites@ Visiten',
	'lien_voir_auteur' => 'Dësen Auteur weisen',
	'ligne' => 'Zeil',
	'login' => 'Verbindung',
	'login_acces_prive' => 'Zougang zum privaten Deel',
	'login_autre_identifiant' => 'sech ënnert engem aneren Login umellen',
	'login_cookie_accepte' => 'Regléiert äre Browser dat e Cookie unhëlt (op mannst fir dëse Site).',
	'login_cookie_oblige' => 'Fir Iech op dësem Site sécher unzemellen musst Dir e Cookie unhuelen.',
	'login_deconnexion_ok' => 'Ofgemellt.',
	'login_erreur_pass' => 'Falscht Passwuert.',
	'login_espace_prive' => 'privaten Deel',
	'login_identifiant_inconnu' => 'De Login « @login@ » ass net bekannt.',
	'login_login' => 'Login:',
	'login_login2' => 'Login',
	'login_login_pass_incorrect' => '(Login oder Passwuert falsch.)',
	'login_motpasseoublie' => 'Passwuert vergiess?',
	'login_non_securise' => 'Opgepasst, dëse Formulaire ass net geséchert.
Wann dir net wëllt dat äert Passwuert ka um Internet ofgefaange ginn, aktivéiert Javascript an ärem Browser an',
	'login_nouvelle_tentative' => 'Neie Versuch',
	'login_par_ici' => 'Dir sidd ugemeld... hei geet et weider...',
	'login_pass2' => 'Passwuert:',
	'login_preferez_refuser' => '<b>Wann dir kee Cookie wëllt</b>, hei ass eng aner (manner sécher) Umeldungs-Method:',
	'login_recharger' => 'dës Säit nei lueden',
	'login_rester_identifie' => 'E puer Deg ugemellt bleiwen', # MODIF
	'login_retour_public' => 'Zeréck op den ëffentleche Site',
	'login_retour_site' => 'Zeréck op de Site',
	'login_retoursitepublic' => 'zeréck op den ëffentleche Site',
	'login_securise' => 'Séchere Login',
	'login_sinscrire' => 'sech aschreiwen', # MODIF
	'login_test_navigateur' => 'Browser/Login-Test',
	'login_verifiez_navigateur' => '(Kontrolléiert op äre Browser d’Passwuert net gespäichert huet...)',

	// M
	'masquer_colonne' => 'Dës Kolonn verstoppen',
	'masquer_trad' => 'Iwwersetzunge verstoppen',
	'module_fichiers_langues' => 'Sprooch-Fichieren',

	// N
	'navigateur_pas_redirige' => 'Wann äre Browser net weider geleet gëtt, da klickt hei.',
	'numero' => 'Nummer',

	// O
	'occurence' => 'Kënnt fir',
	'onglet_affacer_base' => 'Datebank läschen',
	'onglet_auteur' => 'Den Auteur',
	'onglet_contenu_site' => 'Inhalt vum Site',
	'onglet_evolution_visite_mod' => 'Evolutioun',
	'onglet_fonctions_avances' => 'Fortgeschratt Fonctiounen',
	'onglet_informations_personnelles' => 'Perséinlech Informatiounen',
	'onglet_interactivite' => 'Interaktivitéit',
	'onglet_messagerie' => 'Messagerie',
	'onglet_repartition_rubrique' => 'Verdeelung no Rubrik',
	'onglet_save_restaur_base' => 'Datebank späicheren/restauréieren',
	'onglet_vider_cache' => 'Cache läschen',

	// P
	'pass_choix_pass' => 'Wielt äert neit Passwuert:',
	'pass_erreur' => 'Fehler',
	'pass_erreur_acces_refuse' => '<b>Fehler:</b> dir hutt keen Zougang méi zu dësem Site.',
	'pass_erreur_code_inconnu' => '<b>Fehler:</b> dëse Code entsprécht kengem Visiteur deen Zougang zu dësem Site huet.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Fehler:</b> den Email <tt>@email_oubli@</tt> ass net op dësem Site ugemellt.',
	'pass_erreur_non_valide' => '<b>Fehler:</b> den Email <tt>@email_oubli@</tt> ass falsch!',
	'pass_erreur_probleme_technique' => '<b>Fehler:</b> de Message kann duerch technesch Problemer net geschéckt ginn.',
	'pass_espace_prive_bla' => 'De privaten Deel ass fir Visiteuren no enger Umeldung op. Wann dir ugemellt sidd kënnt der d’Artikelen an der Aarbecht kucken, Artikelen virschloen an un de Forumen deelhuelen.', # MODIF
	'pass_forum_bla' => 'Dir hutt probéiert un engem Forum deelzehuelen den fir déi ugemellte Visiteuren reservéiert ass.', # MODIF
	'pass_indiquez_cidessous' => 'Gitt hei den Email un ënner dem der Iech ugemellt hutt. Dir kritt dann e Message mat den Instruktiounen fir ären Zougang erëm ze kréien.',
	'pass_mail_passcookie' => '(dëst ass en automatesche Message)
Fir ären Zougang zum Site
@nom_site_spip@ (@adresse_site@)
erëm ze kréien, surft op dës URL:

@sendcookie@

Dir kënnt do e neit Passwuert aginn an Iech um Site umellen.

', # MODIF
	'pass_mot_oublie' => 'Passwuert vergiess',
	'pass_nouveau_enregistre' => 'Äert neit Passwuert ass gespäichert.',
	'pass_nouveau_pass' => 'Neit Passwuert',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Vergiessen vum Passwuert',
	'pass_procedure_changer' => 'Mir mussen är Identitéit kontrolléieren fir äert Passwuert ze änneren. Dofir gitt ons d’Email-Adress un déi zu ärem Login gehéiert.', # MODIF
	'pass_quitter_fenetre' => 'Dës Fënster zoumaachen',
	'pass_rappel_login' => 'Rappel: äre Login ass "@login@".',
	'pass_recevoir_mail' => 'Dir kritt e Message mat Instruktiounen fir den Zougang zum Site erëm ze kréien.', # MODIF
	'pass_retour_public' => 'Zeréck op den ëffentleche Site',
	'pass_rien_a_faire_ici' => 'Hei ass näischt lass.',
	'pass_vousinscrire' => 'Iech op dësem Site aschreiwen',
	'precedent' => 'Zeréck',
	'previsualisation' => 'Virschau',
	'previsualiser' => 'Virschau kucken',

	// R
	'retour' => 'Zeréck',

	// S
	'spip_conforme_dtd' => 'SPIP hëlt dëst Dokument als konform zu sengem DOCTYPE un:',
	'squelette' => 'Skelett',
	'squelette_inclus_ligne' => 'Skelett abegraff, Zeil',
	'squelette_ligne' => 'Skelett, Zeil',
	'stats_visites_et_popularite' => '@visites@ Visiten; Popularitéit: @popularite@',
	'suivant' => 'Weider',

	// T
	'taille_go' => '@taille@ GB',
	'taille_ko' => '@taille@ kB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ Byte',
	'taille_octets_bi' => '@taille@ Byte',
	'texte_actualite_site_1' => 'Wann dir mam Interface familiariséiert sidd, da kënnt der op "',
	'texte_actualite_site_2' => 'kompletten Interface klicken',
	'texte_actualite_site_3' => '" fir méi Méiglechkeeten ze weisen.',
	'texte_creation_automatique_vignette' => 'Automatesch Vignetten maachen ass op dësem Site ageschalt. Wann dir mat engem Formulaire Biller am Format @gd_formats@ eroplued, da kréien se eng Vignette vun enger maximaler Gréisst vun @taille_preview@ Pixel.',
	'texte_documents_associes' => 'Dës Dokumenter sinn un den Artikel gebonnen, awer net direkt agefügt. Jee no Design vum Site ginn se als verlinkten Dokumenter gewisen.',
	'texte_erreur_mise_niveau_base' => 'Datebank-Fehler beim Update.
D’Bild <b>@fichier@</b> ass net duerchgaang (Artikel @id_article@).
Notéiert dës Referenz, probéiert nach eng Kéier, a kontrolléiert op d’Biller an den Artikelen gewise ginn.',
	'texte_erreur_visiteur' => 'Dir hutt probéiert mat engem net erlaabte Login an de privaten Deel ze goen.',
	'texte_inc_auth_1' => 'Dir sidd ugemellt mam Login <b>@auth_login@</b>, mais dëse Login gëtt et net méi an der Datebank.
Probéiert ',
	'texte_inc_auth_2' => 'Iech unzemellen',
	'texte_inc_auth_3' => ', eventuell nodeems der äre Browser nei gestart hutt.',
	'texte_inc_config' => 'D’Ännerungen op dëse Säiten beaflossen de Fonctionnement vun ärem Site ganz staark. Maacht näischt ier der de SPIP-System richteg kennt.<br /><br /><b>Generell ass unzeroden, dës Säiten dem Webmaster vun ärem Site ze iwwerloossen.</b>',
	'texte_inc_meta_1' => 'De System huet e Fehler fonnt beim Schreiwen vum Fichier <code>@fichier@</code>. Als Administrateur vum Site,', # MODIF
	'texte_inc_meta_2' => 'kontrolléiert d’Schreif-Rechter',
	'texte_inc_meta_3' => 'am Dossier <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'an der Aarbecht',
	'texte_statut_poubelle' => 'an der Dreckskëscht',
	'texte_statut_propose_evaluation' => 'virgeschloen',
	'texte_statut_publie' => 'verëffentlecht',
	'texte_statut_refuse' => 'ofgeleent',
	'titre_ajouter_mot_cle' => 'SCHLËSSELWUERT BÄIFLÉCKEN:',
	'titre_cadre_raccourcis' => 'OFKIERZUNG:',
	'titre_changer_couleur_interface' => 'Faarf vum Interface änneren',
	'titre_image_admin_article' => 'Dir kënnt dësen Artikel verwalten',
	'titre_image_administrateur' => 'Administrateur', # MODIF
	'titre_image_aide' => 'Hëllef fir dëst Element',
	'titre_image_auteur_supprime' => 'Geläschten Auteur',
	'titre_image_redacteur' => 'Redakter ouni Zougang',
	'titre_image_redacteur_02' => 'Redakter',
	'titre_image_selecteur' => 'De lijst Bekijk ',
	'titre_image_visiteur' => 'Visiteur',
	'titre_joindre_document' => 'DOKUMENT BÄIFLÉCKEN',
	'titre_mots_cles' => 'SCHLËSSELWIERDER',
	'titre_probleme_technique' => 'Opgepasst: e Problem mam SQL-Server verhënnert den Zougang op dësen Deel vum Site. Merci fir är Gedold.',
	'titre_publier_document' => 'DOKUMENT AN DËSER RUBRIK VERËFFENTLECHEN',
	'titre_signatures_attente' => 'Ënnerschrëften déi op Bestätegung waarden',
	'titre_signatures_confirmees' => 'Bestätegt Ënnerschrëften',
	'titre_statistiques' => 'Statistik vum Site',
	'titre_titre_document' => 'Titel vum Dokument:',
	'todo' => 'kënnt nach',
	'trad_reference' => '(Referenz vun den Iwwersetzungen)',

	// Z
	'zbug_balise_b_aval' => ': B-Tag drënner',
	'zbug_balise_inexistante' => 'Tag @balise@ falsch deklaréiert vir @from@',
	'zbug_balise_sans_argument' => 'Argument feelt am Tag @balise@',
	'zbug_boucle' => '-eidel-',
	'zbug_boucle_recursive_undef' => 'Rekursiv Boucle net definéiert: @nom@',
	'zbug_calcul' => 'Berechnung',
	'zbug_champ_hors_boucle' => 'Feld @champ@ ausserhalb vun der Boucle',
	'zbug_champ_hors_motif' => 'Feld @champ@ ausserhalb vun engem Kontext @motif@',
	'zbug_code' => '-Code-',
	'zbug_critere_inconnu' => 'Onbekannte Critère @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} ob enger Tafel ouni atomare Primärschlessel',
	'zbug_distant_interdit' => 'Extern verbueden',
	'zbug_doublon_table_sans_cle_primaire' => 'Duebel Valeuren an enger Tabell ouni atomare primäre Schlëssel',
	'zbug_doublon_table_sans_index' => 'Verdueblung an enger Tabell ouni Index',
	'zbug_erreur_boucle_double' => 'Duebel Definitioun vun der Boucle @id@',
	'zbug_erreur_boucle_fermant' => 'Boucle @id@ net zougemaach',
	'zbug_erreur_boucle_syntaxe' => 'Falsch Syntax vun der Boucle @id@',
	'zbug_erreur_compilation' => 'Kompilatiouns-Fehler',
	'zbug_erreur_execution_page' => 'Ausféierungs-Fehler',
	'zbug_erreur_filtre' => 'Filter @filtre@ net definéiert',
	'zbug_erreur_meme_parent' => 'De Critère {meme_parent} ass just fir d’Boucle (FORUMS) oder (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Fehler am Skelett',
	'zbug_hors_compilation' => 'Ausserhalb vun der Kompilatioun',
	'zbug_info_erreur_squelette' => 'Fehler um Site',
	'zbug_inversion_ordre_inexistant' => 'Inversioun vun enger Uerdnung déi et net gëtt',
	'zbug_pagination_sans_critere' => 'Tag #PAGINATION ouni Critère {pagination} oder an enger rekursiver Boucle benotzt',
	'zbug_parametres_inclus_incorrects' => 'Falschen Inclusiouns-Parameter: @param@',
	'zbug_profile' => 'Rechenzäit: @time@',
	'zbug_resultat' => '-eidel-',
	'zbug_serveur_indefini' => 'SQL-Server net definéiert',
	'zbug_statistiques' => 'Statistik vun den SQL-Query’en, klasséiert no der Längt',
	'zbug_table_inconnue' => 'Onbekannten SQL-Tabell "@table@"',
	'zxml_connus_attributs' => 'Bekannten Attributer',
	'zxml_de' => 'vun',
	'zxml_inconnu_attribut' => 'Onbekannten Attribut',
	'zxml_inconnu_balise' => 'Onbekannten Tag',
	'zxml_inconnu_entite' => 'Onbekannten Entitéit',
	'zxml_inconnu_id' => 'Onbekannten ID',
	'zxml_mais_de' => 'mais vun',
	'zxml_non_conforme' => 'ass net konform zum Motiv',
	'zxml_non_fils' => 'ass kee Kand vun',
	'zxml_nonvide_balise' => 'Tag net eidel',
	'zxml_obligatoire_attribut' => 'Obligatorescht Attribut, fehlt awer an',
	'zxml_succession_fils_incorrecte' => 'Reiefolleg vun de Kanner net richteg',
	'zxml_survoler' => 'driwwer fléien fir déi Richteg ze gesinn',
	'zxml_valeur_attribut' => 'Valeur vum Attribut',
	'zxml_vide_balise' => 'Eidelen Tag',
	'zxml_vu' => 'virdru gesinn',
];
